SNPs Banner
===========
The SNPs banner is composed of nucleotides from
`GRCh38 mitochondrial DNA <https://www.ncbi.nlm.nih.gov/nuccore/NC_012920.1>`_. SNPs are
represented by lighter colored nucleotides.

The SVG file was modified from a version created with
`macSVG <https://github.com/dsward2/macsvg/>`_.

The color scheme was generated by `ColorBrewer <http://colorbrewer2.org/>`_.

SNPs
----
The SNPs highlighted in the banner were identified with the
`UCSC Genome Browser <https://genome.ucsc.edu/>`_. The dbSNP accessions for the SNPs are as
follows:

* rs3883917
* rs370271105
* rs3087742
* rs369034419
* rs147830800
* rs369070397
* rs144402189
* rs139684161
* rs375589100
* rs370482130
* rs62581312
* rs117135796
* rs370716192
* rs41473347
* rs113913230
* rs368807878
* rs371543232
* rs2857291
* rs72619362
* rs372099630
* rs3135032
* rs369669319
* rs368534078
* rs372889209
* rs372439069
* rs41531144
* rs372946833
* rs41323649
* rs368463610
* rs3937037
* rs375896687
* rs145412228
* rs376013487
* rs372529808
* rs41334645
* rs372003323
* rs41400048
* rs2853515
* rs201801609
* rs41528348
* rs3927813
* rs66492218
* rs371975106
* rs373732637
* rs117394573
* rs3883865
* rs28678375

References
~~~~~~~~~~
* Sherry ST, Ward MH, Kholodov M, Baker J, Phan L, Smigielski EM, Sirotkin K. dbSNP: the NCBI
  database of genetic variation. Nucleic Acids Res. 2001 Jan 1; 29(1):308-11.
* Database of Single Nucleotide Polymorphisms (dbSNP). Bethesda (MD): National Center for
  Biotechnology Information, National Library of Medicine. dbSNP accession: <listed above> (dbSNP
  Build ID: 142). Available from: http://www.ncbi.nlm.nih.gov/SNP/